@@ -131,8 +131,10 @@ class CortxJupyter(ContentsManager):
         with (yield self.write_lock.acquire()):
             return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
 
+    @gen.coroutine
     def _config(self):
-        cortx_auths = self.authentication.get_credentials()
+        print('before')
+        cortx_auths = yield self.authentication.get_credentials()
         print(cortx_auths)
         print('type',type(cortx_auths))
         creds = {'region_name':self.region_name,'bucket_name':self.bucket_name,
